Date: 2022-10-01T06:39:31+00:00

Actual source code: stregis.c
slepc-3.18.0 2022-10-01
Report Typos and Errors

      1: /*
      2:    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
      3:    SLEPc - Scalable Library for Eigenvalue Problem Computations
      4:    Copyright (c) 2002-, Universitat Politecnica de Valencia, Spain

      6:    This file is part of SLEPc.
      7:    SLEPc is distributed under a 2-clause BSD license (see LICENSE).
      8:    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
      9: */

     11: #include <slepc/private/stimpl.h>

     13: SLEPC_EXTERN PetscErrorCode STCreate_Shell(ST);
     14: SLEPC_EXTERN PetscErrorCode STCreate_Shift(ST);
     15: SLEPC_EXTERN PetscErrorCode STCreate_Sinvert(ST);
     16: SLEPC_EXTERN PetscErrorCode STCreate_Cayley(ST);
     17: SLEPC_EXTERN PetscErrorCode STCreate_Precond(ST);
     18: SLEPC_EXTERN PetscErrorCode STCreate_Filter(ST);

     20: /*@C
     21:    STRegisterAll - Registers all of the spectral transformations in the ST package.

     23:    Not Collective

     25:    Level: advanced

     27: .seealso: STRegister()
     28: @*/
     29: PetscErrorCode STRegisterAll(void)
     30: {
     31:   if (STRegisterAllCalled) return 0;
     32:   STRegisterAllCalled = PETSC_TRUE;
     33:   STRegister(STSHELL,STCreate_Shell);
     34:   STRegister(STSHIFT,STCreate_Shift);
     35:   STRegister(STSINVERT,STCreate_Sinvert);
     36:   STRegister(STCAYLEY,STCreate_Cayley);
     37:   STRegister(STPRECOND,STCreate_Precond);
     38:   STRegister(STFILTER,STCreate_Filter);
     39:   return 0;
     40: }